aboutsummaryrefslogtreecommitdiff
path: root/tools/plink/terminal.h
diff options
context:
space:
mode:
Diffstat (limited to 'tools/plink/terminal.h')
-rw-r--r--tools/plink/terminal.h58
1 files changed, 52 insertions, 6 deletions
diff --git a/tools/plink/terminal.h b/tools/plink/terminal.h
index 6d3b1c544..924cf56b9 100644
--- a/tools/plink/terminal.h
+++ b/tools/plink/terminal.h
@@ -233,13 +233,13 @@ struct terminal_tag {
struct unicode_data *ucsdata;
/*
* We maintain a full _copy_ of a Config structure here, not
* merely a pointer to it. That way, when we're passed a new
* one for reconfiguration, we can check the differences and
* adjust the _current_ setting of (e.g.) auto wrap mode rather
* than only the default.
*/
- Config cfg;
+ Conf *conf;
/*
* from_backend calls term_out, but it can also be called from
@@ -273,6 +273,52 @@ struct terminal_tag {
int wcFromTo_size;
struct bidi_cache_entry *pre_bidi_cache, *post_bidi_cache;
int bidi_cache_size;
+
+ /*
+ * We copy a bunch of stuff out of the Conf structure into local
+ * fields in the Terminal structure, to avoid the repeated
+ * tree234 lookups which would be involved in fetching them from
+ * the former every time.
+ */
+ int ansi_colour;
+ char *answerback;
+ int answerbacklen;
+ int arabicshaping;
+ int beep;
+ int bellovl;
+ int bellovl_n;
+ int bellovl_s;
+ int bellovl_t;
+ int bidi;
+ int bksp_is_delete;
+ int blink_cur;
+ int blinktext;
+ int cjk_ambig_wide;
+ int conf_height;
+ int conf_width;
+ int crhaslf;
+ int erase_to_scrollback;
+ int funky_type;
+ int lfhascr;
+ int logflush;
+ int logtype;
+ int mouse_override;
+ int nethack_keypad;
+ int no_alt_screen;
+ int no_applic_c;
+ int no_applic_k;
+ int no_dbackspace;
+ int no_mouse_rep;
+ int no_remote_charset;
+ int no_remote_resize;
+ int no_remote_wintitle;
+ int rawcnp;
+ int rect_select;
+ int remote_qtitle_action;
+ int rxvt_homeend;
+ int scroll_on_disp;
+ int scroll_on_key;
+ int xterm_256_colour;
};
#define in_utf(term) ((term)->utf || (term)->ucsdata->line_codepage==CP_UTF8)
@@ -233,13 +233,13 @@ struct terminal_tag {
struct unicode_data *ucsdata;
/*
- * We maintain a full _copy_ of a Config structure here, not
- * merely a pointer to it. That way, when we're passed a new
- * one for reconfiguration, we can check the differences and
- * adjust the _current_ setting of (e.g.) auto wrap mode rather
- * than only the default.
+ * We maintain a full copy of a Conf here, not merely a pointer
+ * to it. That way, when we're passed a new one for
+ * reconfiguration, we can check the differences and adjust the
+ * _current_ setting of (e.g.) auto wrap mode rather than only
+ * the default.
*/